# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: redhat.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='redhat.proto',
  package='strobesbufs.scrappers.redhat',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0credhat.proto\x12\x1cstrobesbufs.scrappers.redhat\"\x97\x02\n\x06Redhat\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0b\n\x03\x63ve\x18\x02 \x01(\t\x12\x10\n\x08severity\x18\x03 \x01(\x05\x12\x16\n\x0epublished_date\x18\x04 \x01(\t\x12\x12\n\nadvisories\x18\x05 \x03(\t\x12\x10\n\x08\x62ugzilla\x18\x06 \x01(\t\x12\x1c\n\x14\x62ugzilla_description\x18\x07 \x01(\t\x12\x0c\n\x04\x63vss\x18\x08 \x01(\x02\x12\x13\n\x0b\x63vss_vector\x18\t \x01(\t\x12\x0b\n\x03\x63we\x18\n \x01(\t\x12\x19\n\x11\x61\x66\x66\x65\x63ted_packages\x18\x0b \x03(\t\x12\x12\n\nreferences\x18\x0c \x03(\t\x12\r\n\x05\x63vss3\x18\r \x01(\t\x12\x14\n\x0c\x63vss3_vector\x18\x0e \x01(\t\"B\n\nRedhatList\x12\x34\n\x06redhat\x18\x01 \x03(\x0b\x32$.strobesbufs.scrappers.redhat.Redhatb\x06proto3'
)




_REDHAT = _descriptor.Descriptor(
  name='Redhat',
  full_name='strobesbufs.scrappers.redhat.Redhat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.redhat.Redhat.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.redhat.Redhat.cve', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity', full_name='strobesbufs.scrappers.redhat.Redhat.severity', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_date', full_name='strobesbufs.scrappers.redhat.Redhat.published_date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advisories', full_name='strobesbufs.scrappers.redhat.Redhat.advisories', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bugzilla', full_name='strobesbufs.scrappers.redhat.Redhat.bugzilla', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bugzilla_description', full_name='strobesbufs.scrappers.redhat.Redhat.bugzilla_description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss', full_name='strobesbufs.scrappers.redhat.Redhat.cvss', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss_vector', full_name='strobesbufs.scrappers.redhat.Redhat.cvss_vector', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cwe', full_name='strobesbufs.scrappers.redhat.Redhat.cwe', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affected_packages', full_name='strobesbufs.scrappers.redhat.Redhat.affected_packages', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='references', full_name='strobesbufs.scrappers.redhat.Redhat.references', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss3', full_name='strobesbufs.scrappers.redhat.Redhat.cvss3', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss3_vector', full_name='strobesbufs.scrappers.redhat.Redhat.cvss3_vector', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=326,
)


_REDHATLIST = _descriptor.Descriptor(
  name='RedhatList',
  full_name='strobesbufs.scrappers.redhat.RedhatList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='redhat', full_name='strobesbufs.scrappers.redhat.RedhatList.redhat', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=394,
)

_REDHATLIST.fields_by_name['redhat'].message_type = _REDHAT
DESCRIPTOR.message_types_by_name['Redhat'] = _REDHAT
DESCRIPTOR.message_types_by_name['RedhatList'] = _REDHATLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Redhat = _reflection.GeneratedProtocolMessageType('Redhat', (_message.Message,), {
  'DESCRIPTOR' : _REDHAT,
  '__module__' : 'redhat_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.redhat.Redhat)
  })
_sym_db.RegisterMessage(Redhat)

RedhatList = _reflection.GeneratedProtocolMessageType('RedhatList', (_message.Message,), {
  'DESCRIPTOR' : _REDHATLIST,
  '__module__' : 'redhat_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.redhat.RedhatList)
  })
_sym_db.RegisterMessage(RedhatList)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/common.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/common.proto',
  package='strobesbufs.messier.common',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n strobesbufs/messier/common.proto\x12\x1astrobesbufs.messier.common*T\n\x06Status\x12\x0b\n\x07PENDING\x10\x00\x12\x0b\n\x07STARTED\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x0b\n\x07\x46\x41ILURE\x10\x03\x12\t\n\x05RETRY\x10\x04\x12\x0b\n\x07REVOKED\x10\x05*E\n\x08LogLevel\x12\t\n\x05\x44\x45\x42UG\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08\x43RITICAL\x10\x04\x62\x06proto3'
)

_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='strobesbufs.messier.common.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RETRY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REVOKED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=64,
  serialized_end=148,
)
_sym_db.RegisterEnumDescriptor(_STATUS)

Status = enum_type_wrapper.EnumTypeWrapper(_STATUS)
_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='strobesbufs.messier.common.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=150,
  serialized_end=219,
)
_sym_db.RegisterEnumDescriptor(_LOGLEVEL)

LogLevel = enum_type_wrapper.EnumTypeWrapper(_LOGLEVEL)
PENDING = 0
STARTED = 1
SUCCESS = 2
FAILURE = 3
RETRY = 4
REVOKED = 5
DEBUG = 0
INFO = 1
WARNING = 2
ERROR = 3
CRITICAL = 4


DESCRIPTOR.enum_types_by_name['Status'] = _STATUS
DESCRIPTOR.enum_types_by_name['LogLevel'] = _LOGLEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: analyzers_service.proto

from strobesbufs.analyzers import analyzers_pb2 as analyzers__pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name='analyzers_service.proto',
    package='strobesbufs.analyzers.analyzer_service',
    syntax='proto3',
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x17\x61nalyzers_service.proto\x12&strobesbufs.analyzers.analyzer_service\x1a\x0f\x61nalyzers.proto\"\xe9\x03\n\x0eRunTaskRequest\x12\x10\n\x08\x61nalyzer\x18\x01 \x01(\t\x12\x0e\n\x06parser\x18\x02 \x01(\t\x12\x0b\n\x03vcs\x18\x03 \x01(\t\x12U\n\x08vcs_data\x18\x04 \x03(\x0b\x32\x43.strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry\x12W\n\tscan_data\x18\x05 \x03(\x0b\x32\x44.strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry\x12U\n\x08\x65nv_data\x18\x06 \x03(\x0b\x32\x43.strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry\x12\x10\n\x08\x66ilename\x18\x07 \x01(\t\x1a.\n\x0cVcsDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rScanDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0c\x45nvDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x0fRunTaskResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\x1f\n\x11TaskStatusRequest\x12\n\n\x02id\x18\x01 \x01(\t\"?\n\x12TaskStatusResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1d\n\x0fStopTaskRequest\x12\n\n\x02id\x18\x01 \x01(\t\"=\n\x10StopTaskResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1f\n\x11GetResultsRequest\x12\n\n\x02id\x18\x01 \x01(\t\"M\n\x12GetResultsResponse\x12\x37\n\x07results\x18\x01 \x01(\x0b\x32&.strobesbufs.analyzers.analyzer.Result\"O\n\x0fTaskLogsRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nnext_token\x18\x02 \x01(\t\x12\r\n\x05start\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\"O\n\x10TaskLogsResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0c\n\x04logs\x18\x03 \x01(\t\x12\x12\n\nnext_token\x18\x04 \x01(\t2\x9f\x05\n\rRunnerService\x12|\n\x07RunTask\x12\x36.strobesbufs.analyzers.analyzer_service.RunTaskRequest\x1a\x37.strobesbufs.analyzers.analyzer_service.RunTaskResponse\"\x00\x12\x85\x01\n\nTaskStatus\x12\x39.strobesbufs.analyzers.analyzer_service.TaskStatusRequest\x1a:.strobesbufs.analyzers.analyzer_service.TaskStatusResponse\"\x00\x12\x7f\n\x08StopTask\x12\x37.strobesbufs.analyzers.analyzer_service.StopTaskRequest\x1a\x38.strobesbufs.analyzers.analyzer_service.StopTaskResponse\"\x00\x12\x7f\n\x08TaskLogs\x12\x37.strobesbufs.analyzers.analyzer_service.TaskLogsRequest\x1a\x38.strobesbufs.analyzers.analyzer_service.TaskLogsResponse\"\x00\x12\x85\x01\n\nGetResults\x12\x39.strobesbufs.analyzers.analyzer_service.GetResultsRequest\x1a:.strobesbufs.analyzers.analyzer_service.GetResultsResponse\"\x00\x62\x06proto3',
    dependencies=[analyzers__pb2.DESCRIPTOR, ])


_RUNTASKREQUEST_VCSDATAENTRY = _descriptor.Descriptor(
    name='VcsDataEntry',
    full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry.key', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='value', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry.value', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=b'8\001',
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=431,
    serialized_end=477,
)

_RUNTASKREQUEST_SCANDATAENTRY = _descriptor.Descriptor(
    name='ScanDataEntry',
    full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry.key', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='value', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry.value', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=b'8\001',
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=479,
    serialized_end=526,
)

_RUNTASKREQUEST_ENVDATAENTRY = _descriptor.Descriptor(
    name='EnvDataEntry',
    full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry.key', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='value', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry.value', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=b'8\001',
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=528,
    serialized_end=574,
)

_RUNTASKREQUEST = _descriptor.Descriptor(
    name='RunTaskRequest',
    full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='analyzer', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.analyzer', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='parser', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.parser', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='vcs', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.vcs', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='vcs_data', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.vcs_data', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='scan_data', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.scan_data', index=4,
            number=5, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='env_data', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.env_data', index=5,
            number=6, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='filename', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.filename', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[_RUNTASKREQUEST_VCSDATAENTRY,
                  _RUNTASKREQUEST_SCANDATAENTRY, _RUNTASKREQUEST_ENVDATAENTRY, ],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=85,
    serialized_end=574,
)


_RUNTASKRESPONSE = _descriptor.Descriptor(
    name='RunTaskResponse',
    full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='error', full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse.error', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='message', full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse.message', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=576,
    serialized_end=637,
)


_TASKSTATUSREQUEST = _descriptor.Descriptor(
    name='TaskStatusRequest',
    full_name='strobesbufs.analyzers.analyzer_service.TaskStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusRequest.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=639,
    serialized_end=670,
)


_TASKSTATUSRESPONSE = _descriptor.Descriptor(
    name='TaskStatusResponse',
    full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='error', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse.error', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='status', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse.status', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=672,
    serialized_end=735,
)


_STOPTASKREQUEST = _descriptor.Descriptor(
    name='StopTaskRequest',
    full_name='strobesbufs.analyzers.analyzer_service.StopTaskRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='strobesbufs.analyzers.analyzer_service.StopTaskRequest.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=737,
    serialized_end=766,
)


_STOPTASKRESPONSE = _descriptor.Descriptor(
    name='StopTaskResponse',
    full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='error', full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse.error', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='status', full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse.status', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=768,
    serialized_end=829,
)


_GETRESULTSREQUEST = _descriptor.Descriptor(
    name='GetResultsRequest',
    full_name='strobesbufs.analyzers.analyzer_service.GetResultsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='strobesbufs.analyzers.analyzer_service.GetResultsRequest.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=831,
    serialized_end=862,
)


_GETRESULTSRESPONSE = _descriptor.Descriptor(
    name='GetResultsResponse',
    full_name='strobesbufs.analyzers.analyzer_service.GetResultsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='results', full_name='strobesbufs.analyzers.analyzer_service.GetResultsResponse.results', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=864,
    serialized_end=941,
)


_TASKLOGSREQUEST = _descriptor.Descriptor(
    name='TaskLogsRequest',
    full_name='strobesbufs.analyzers.analyzer_service.TaskLogsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='strobesbufs.analyzers.analyzer_service.TaskLogsRequest.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='next_token', full_name='strobesbufs.analyzers.analyzer_service.TaskLogsRequest.next_token', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='start', full_name='strobesbufs.analyzers.analyzer_service.TaskLogsRequest.start', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='limit', full_name='strobesbufs.analyzers.analyzer_service.TaskLogsRequest.limit', index=3,
            number=4, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=943,
    serialized_end=1022,
)


_TASKLOGSRESPONSE = _descriptor.Descriptor(
    name='TaskLogsResponse',
    full_name='strobesbufs.analyzers.analyzer_service.TaskLogsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='strobesbufs.analyzers.analyzer_service.TaskLogsResponse.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='error', full_name='strobesbufs.analyzers.analyzer_service.TaskLogsResponse.error', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='logs', full_name='strobesbufs.analyzers.analyzer_service.TaskLogsResponse.logs', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='next_token', full_name='strobesbufs.analyzers.analyzer_service.TaskLogsResponse.next_token', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1024,
    serialized_end=1103,
)

_RUNTASKREQUEST_VCSDATAENTRY.containing_type = _RUNTASKREQUEST
_RUNTASKREQUEST_SCANDATAENTRY.containing_type = _RUNTASKREQUEST
_RUNTASKREQUEST_ENVDATAENTRY.containing_type = _RUNTASKREQUEST
_RUNTASKREQUEST.fields_by_name['vcs_data'].message_type = _RUNTASKREQUEST_VCSDATAENTRY
_RUNTASKREQUEST.fields_by_name['scan_data'].message_type = _RUNTASKREQUEST_SCANDATAENTRY
_RUNTASKREQUEST.fields_by_name['env_data'].message_type = _RUNTASKREQUEST_ENVDATAENTRY
_GETRESULTSRESPONSE.fields_by_name['results'].message_type = analyzers__pb2._RESULT
DESCRIPTOR.message_types_by_name['RunTaskRequest'] = _RUNTASKREQUEST
DESCRIPTOR.message_types_by_name['RunTaskResponse'] = _RUNTASKRESPONSE
DESCRIPTOR.message_types_by_name['TaskStatusRequest'] = _TASKSTATUSREQUEST
DESCRIPTOR.message_types_by_name['TaskStatusResponse'] = _TASKSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['StopTaskRequest'] = _STOPTASKREQUEST
DESCRIPTOR.message_types_by_name['StopTaskResponse'] = _STOPTASKRESPONSE
DESCRIPTOR.message_types_by_name['GetResultsRequest'] = _GETRESULTSREQUEST
DESCRIPTOR.message_types_by_name['GetResultsResponse'] = _GETRESULTSRESPONSE
DESCRIPTOR.message_types_by_name['TaskLogsRequest'] = _TASKLOGSREQUEST
DESCRIPTOR.message_types_by_name['TaskLogsResponse'] = _TASKLOGSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunTaskRequest = _reflection.GeneratedProtocolMessageType('RunTaskRequest', (_message.Message,), {

    'VcsDataEntry': _reflection.GeneratedProtocolMessageType('VcsDataEntry', (_message.Message,), {
        'DESCRIPTOR': _RUNTASKREQUEST_VCSDATAENTRY,
        '__module__': 'analyzers_service_pb2'
        # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry)
    }),

    'ScanDataEntry': _reflection.GeneratedProtocolMessageType('ScanDataEntry', (_message.Message,), {
        'DESCRIPTOR': _RUNTASKREQUEST_SCANDATAENTRY,
        '__module__': 'analyzers_service_pb2'
        # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry)
    }),

    'EnvDataEntry': _reflection.GeneratedProtocolMessageType('EnvDataEntry', (_message.Message,), {
        'DESCRIPTOR': _RUNTASKREQUEST_ENVDATAENTRY,
        '__module__': 'analyzers_service_pb2'
        # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry)
    }),
    'DESCRIPTOR': _RUNTASKREQUEST,
    '__module__': 'analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest)
})
_sym_db.RegisterMessage(RunTaskRequest)
_sym_db.RegisterMessage(RunTaskRequest.VcsDataEntry)
_sym_db.RegisterMessage(RunTaskRequest.ScanDataEntry)
_sym_db.RegisterMessage(RunTaskRequest.EnvDataEntry)

RunTaskResponse = _reflection.GeneratedProtocolMessageType('RunTaskResponse', (_message.Message,), {
    'DESCRIPTOR': _RUNTASKRESPONSE,
    '__module__': 'analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskResponse)
})
_sym_db.RegisterMessage(RunTaskResponse)

TaskStatusRequest = _reflection.GeneratedProtocolMessageType('TaskStatusRequest', (_message.Message,), {
    'DESCRIPTOR': _TASKSTATUSREQUEST,
    '__module__': 'analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.TaskStatusRequest)
})
_sym_db.RegisterMessage(TaskStatusRequest)

TaskStatusResponse = _reflection.GeneratedProtocolMessageType('TaskStatusResponse', (_message.Message,), {
    'DESCRIPTOR': _TASKSTATUSRESPONSE,
    '__module__': 'analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.TaskStatusResponse)
})
_sym_db.RegisterMessage(TaskStatusResponse)

StopTaskRequest = _reflection.GeneratedProtocolMessageType('StopTaskRequest', (_message.Message,), {
    'DESCRIPTOR': _STOPTASKREQUEST,
    '__module__': 'analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.StopTaskRequest)
})
_sym_db.RegisterMessage(StopTaskRequest)

StopTaskResponse = _reflection.GeneratedProtocolMessageType('StopTaskResponse', (_message.Message,), {
    'DESCRIPTOR': _STOPTASKRESPONSE,
    '__module__': 'analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.StopTaskResponse)
})
_sym_db.RegisterMessage(StopTaskResponse)

GetResultsRequest = _reflection.GeneratedProtocolMessageType('GetResultsRequest', (_message.Message,), {
    'DESCRIPTOR': _GETRESULTSREQUEST,
    '__module__': 'analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.GetResultsRequest)
})
_sym_db.RegisterMessage(GetResultsRequest)

GetResultsResponse = _reflection.GeneratedProtocolMessageType('GetResultsResponse', (_message.Message,), {
    'DESCRIPTOR': _GETRESULTSRESPONSE,
    '__module__': 'analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.GetResultsResponse)
})
_sym_db.RegisterMessage(GetResultsResponse)

TaskLogsRequest = _reflection.GeneratedProtocolMessageType('TaskLogsRequest', (_message.Message,), {
    'DESCRIPTOR': _TASKLOGSREQUEST,
    '__module__': 'analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.TaskLogsRequest)
})
_sym_db.RegisterMessage(TaskLogsRequest)

TaskLogsResponse = _reflection.GeneratedProtocolMessageType('TaskLogsResponse', (_message.Message,), {
    'DESCRIPTOR': _TASKLOGSRESPONSE,
    '__module__': 'analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.TaskLogsResponse)
})
_sym_db.RegisterMessage(TaskLogsResponse)


_RUNTASKREQUEST_VCSDATAENTRY._options = None
_RUNTASKREQUEST_SCANDATAENTRY._options = None
_RUNTASKREQUEST_ENVDATAENTRY._options = None

_RUNNERSERVICE = _descriptor.ServiceDescriptor(
    name='RunnerService',
    full_name='strobesbufs.analyzers.analyzer_service.RunnerService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=1106,
    serialized_end=1777,
    methods=[
        _descriptor.MethodDescriptor(
            name='RunTask',
            full_name='strobesbufs.analyzers.analyzer_service.RunnerService.RunTask',
            index=0,
            containing_service=None,
            input_type=_RUNTASKREQUEST,
            output_type=_RUNTASKRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='TaskStatus',
            full_name='strobesbufs.analyzers.analyzer_service.RunnerService.TaskStatus',
            index=1,
            containing_service=None,
            input_type=_TASKSTATUSREQUEST,
            output_type=_TASKSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='StopTask',
            full_name='strobesbufs.analyzers.analyzer_service.RunnerService.StopTask',
            index=2,
            containing_service=None,
            input_type=_STOPTASKREQUEST,
            output_type=_STOPTASKRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='TaskLogs',
            full_name='strobesbufs.analyzers.analyzer_service.RunnerService.TaskLogs',
            index=3,
            containing_service=None,
            input_type=_TASKLOGSREQUEST,
            output_type=_TASKLOGSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetResults',
            full_name='strobesbufs.analyzers.analyzer_service.RunnerService.GetResults',
            index=4,
            containing_service=None,
            input_type=_GETRESULTSREQUEST,
            output_type=_GETRESULTSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ])
_sym_db.RegisterServiceDescriptor(_RUNNERSERVICE)

DESCRIPTOR.services_by_name['RunnerService'] = _RUNNERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/workflows/services.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from strobesbufs.messier.workflows import workflow_pb2 as strobesbufs_dot_messier_dot_workflows_dot_workflow__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/workflows/services.proto',
  package='strobesbufs.messier.workflow.services',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,strobesbufs/messier/workflows/services.proto\x12%strobesbufs.messier.workflow.services\x1a\x1cgoogle/protobuf/struct.proto\x1a,strobesbufs/messier/workflows/workflow.proto\"\'\n\x17WorkflowValidateRequest\x12\x0c\n\x04yaml\x18\x01 \x01(\t\"\x8e\x01\n\x18WorkflowValidateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\'\n\x06\x65rrors\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x38\n\x08workflow\x18\x03 \x01(\x0b\x32&.strobesbufs.messier.workflow.Workflow\"R\n\x16WorkflowExecuteRequest\x12\x38\n\x08workflow\x18\x01 \x01(\x0b\x32&.strobesbufs.messier.workflow.Workflow\"S\n\x17WorkflowExecuteResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\'\n\x06\x65rrors\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x90\x01\n\x11GetResultsRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12K\n\x04type\x18\x02 \x01(\x0e\x32=.strobesbufs.messier.workflow.services.GetResultsRequest.Type\"\"\n\x04Type\x12\x0c\n\x08WORKFLOW\x10\x00\x12\x0c\n\x08\x41NALYZER\x10\x01\">\n\x12GetResultsResponse\x12(\n\x07results\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xc4\x03\n\x0fWorkflowService\x12\x95\x01\n\x10WorkflowValidate\x12>.strobesbufs.messier.workflow.services.WorkflowValidateRequest\x1a?.strobesbufs.messier.workflow.services.WorkflowValidateResponse\"\x00\x12\x92\x01\n\x0fWorkflowExecute\x12=.strobesbufs.messier.workflow.services.WorkflowExecuteRequest\x1a>.strobesbufs.messier.workflow.services.WorkflowExecuteResponse\"\x00\x12\x83\x01\n\nGetResults\x12\x38.strobesbufs.messier.workflow.services.GetResultsRequest\x1a\x39.strobesbufs.messier.workflow.services.GetResultsResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_workflows_dot_workflow__pb2.DESCRIPTOR,])



_GETRESULTSREQUEST_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='strobesbufs.messier.workflow.services.GetResultsRequest.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANALYZER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=629,
  serialized_end=663,
)
_sym_db.RegisterEnumDescriptor(_GETRESULTSREQUEST_TYPE)


_WORKFLOWVALIDATEREQUEST = _descriptor.Descriptor(
  name='WorkflowValidateRequest',
  full_name='strobesbufs.messier.workflow.services.WorkflowValidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='yaml', full_name='strobesbufs.messier.workflow.services.WorkflowValidateRequest.yaml', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=202,
)


_WORKFLOWVALIDATERESPONSE = _descriptor.Descriptor(
  name='WorkflowValidateResponse',
  full_name='strobesbufs.messier.workflow.services.WorkflowValidateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='strobesbufs.messier.workflow.services.WorkflowValidateResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='strobesbufs.messier.workflow.services.WorkflowValidateResponse.errors', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='strobesbufs.messier.workflow.services.WorkflowValidateResponse.workflow', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=347,
)


_WORKFLOWEXECUTEREQUEST = _descriptor.Descriptor(
  name='WorkflowExecuteRequest',
  full_name='strobesbufs.messier.workflow.services.WorkflowExecuteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow', full_name='strobesbufs.messier.workflow.services.WorkflowExecuteRequest.workflow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=431,
)


_WORKFLOWEXECUTERESPONSE = _descriptor.Descriptor(
  name='WorkflowExecuteResponse',
  full_name='strobesbufs.messier.workflow.services.WorkflowExecuteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='strobesbufs.messier.workflow.services.WorkflowExecuteResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='strobesbufs.messier.workflow.services.WorkflowExecuteResponse.errors', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=516,
)


_GETRESULTSREQUEST = _descriptor.Descriptor(
  name='GetResultsRequest',
  full_name='strobesbufs.messier.workflow.services.GetResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.messier.workflow.services.GetResultsRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='strobesbufs.messier.workflow.services.GetResultsRequest.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETRESULTSREQUEST_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=663,
)


_GETRESULTSRESPONSE = _descriptor.Descriptor(
  name='GetResultsResponse',
  full_name='strobesbufs.messier.workflow.services.GetResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='strobesbufs.messier.workflow.services.GetResultsResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=727,
)

_WORKFLOWVALIDATERESPONSE.fields_by_name['errors'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_WORKFLOWVALIDATERESPONSE.fields_by_name['workflow'].message_type = strobesbufs_dot_messier_dot_workflows_dot_workflow__pb2._WORKFLOW
_WORKFLOWEXECUTEREQUEST.fields_by_name['workflow'].message_type = strobesbufs_dot_messier_dot_workflows_dot_workflow__pb2._WORKFLOW
_WORKFLOWEXECUTERESPONSE.fields_by_name['errors'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_GETRESULTSREQUEST.fields_by_name['type'].enum_type = _GETRESULTSREQUEST_TYPE
_GETRESULTSREQUEST_TYPE.containing_type = _GETRESULTSREQUEST
_GETRESULTSRESPONSE.fields_by_name['results'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['WorkflowValidateRequest'] = _WORKFLOWVALIDATEREQUEST
DESCRIPTOR.message_types_by_name['WorkflowValidateResponse'] = _WORKFLOWVALIDATERESPONSE
DESCRIPTOR.message_types_by_name['WorkflowExecuteRequest'] = _WORKFLOWEXECUTEREQUEST
DESCRIPTOR.message_types_by_name['WorkflowExecuteResponse'] = _WORKFLOWEXECUTERESPONSE
DESCRIPTOR.message_types_by_name['GetResultsRequest'] = _GETRESULTSREQUEST
DESCRIPTOR.message_types_by_name['GetResultsResponse'] = _GETRESULTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WorkflowValidateRequest = _reflection.GeneratedProtocolMessageType('WorkflowValidateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWVALIDATEREQUEST,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.WorkflowValidateRequest)
  })
_sym_db.RegisterMessage(WorkflowValidateRequest)

WorkflowValidateResponse = _reflection.GeneratedProtocolMessageType('WorkflowValidateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWVALIDATERESPONSE,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.WorkflowValidateResponse)
  })
_sym_db.RegisterMessage(WorkflowValidateResponse)

WorkflowExecuteRequest = _reflection.GeneratedProtocolMessageType('WorkflowExecuteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWEXECUTEREQUEST,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.WorkflowExecuteRequest)
  })
_sym_db.RegisterMessage(WorkflowExecuteRequest)

WorkflowExecuteResponse = _reflection.GeneratedProtocolMessageType('WorkflowExecuteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWEXECUTERESPONSE,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.WorkflowExecuteResponse)
  })
_sym_db.RegisterMessage(WorkflowExecuteResponse)

GetResultsRequest = _reflection.GeneratedProtocolMessageType('GetResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSREQUEST,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.GetResultsRequest)
  })
_sym_db.RegisterMessage(GetResultsRequest)

GetResultsResponse = _reflection.GeneratedProtocolMessageType('GetResultsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSE,
  '__module__' : 'strobesbufs.messier.workflows.services_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.services.GetResultsResponse)
  })
_sym_db.RegisterMessage(GetResultsResponse)



_WORKFLOWSERVICE = _descriptor.ServiceDescriptor(
  name='WorkflowService',
  full_name='strobesbufs.messier.workflow.services.WorkflowService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=730,
  serialized_end=1182,
  methods=[
  _descriptor.MethodDescriptor(
    name='WorkflowValidate',
    full_name='strobesbufs.messier.workflow.services.WorkflowService.WorkflowValidate',
    index=0,
    containing_service=None,
    input_type=_WORKFLOWVALIDATEREQUEST,
    output_type=_WORKFLOWVALIDATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WorkflowExecute',
    full_name='strobesbufs.messier.workflow.services.WorkflowService.WorkflowExecute',
    index=1,
    containing_service=None,
    input_type=_WORKFLOWEXECUTEREQUEST,
    output_type=_WORKFLOWEXECUTERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetResults',
    full_name='strobesbufs.messier.workflow.services.WorkflowService.GetResults',
    index=2,
    containing_service=None,
    input_type=_GETRESULTSREQUEST,
    output_type=_GETRESULTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKFLOWSERVICE)

DESCRIPTOR.services_by_name['WorkflowService'] = _WORKFLOWSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msbulletin.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='msbulletin.proto',
  package='strobesbufs.scrappers.msbulletin',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10msbulletin.proto\x12 strobesbufs.scrappers.msbulletin\"#\n\x07Product\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xf8\x01\n\nMsbulletin\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0b\n\x03\x63ve\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0e\n\x06impact\x18\x05 \x01(\t\x12\x44\n\x11impacted_products\x18\x06 \x03(\x0b\x32).strobesbufs.scrappers.msbulletin.Product\x12\x10\n\x08severity\x18\x07 \x01(\x05\x12\x16\n\x0epublished_date\x18\x08 \x01(\t\x12\x15\n\rlast_modified\x18\t \x01(\t\x12\x12\n\nreferences\x18\n \x03(\t\"J\n\x06Result\x12@\n\nmsbulletin\x18\x01 \x03(\x0b\x32,.strobesbufs.scrappers.msbulletin.Msbulletinb\x06proto3'
)




_PRODUCT = _descriptor.Descriptor(
  name='Product',
  full_name='strobesbufs.scrappers.msbulletin.Product',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.scrappers.msbulletin.Product.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='strobesbufs.scrappers.msbulletin.Product.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=89,
)


_MSBULLETIN = _descriptor.Descriptor(
  name='Msbulletin',
  full_name='strobesbufs.scrappers.msbulletin.Msbulletin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.msbulletin.Msbulletin.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.msbulletin.Msbulletin.cve', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='strobesbufs.scrappers.msbulletin.Msbulletin.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='strobesbufs.scrappers.msbulletin.Msbulletin.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='impact', full_name='strobesbufs.scrappers.msbulletin.Msbulletin.impact', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='impacted_products', full_name='strobesbufs.scrappers.msbulletin.Msbulletin.impacted_products', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity', full_name='strobesbufs.scrappers.msbulletin.Msbulletin.severity', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_date', full_name='strobesbufs.scrappers.msbulletin.Msbulletin.published_date', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_modified', full_name='strobesbufs.scrappers.msbulletin.Msbulletin.last_modified', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='references', full_name='strobesbufs.scrappers.msbulletin.Msbulletin.references', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=340,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.msbulletin.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='msbulletin', full_name='strobesbufs.scrappers.msbulletin.Result.msbulletin', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=416,
)

_MSBULLETIN.fields_by_name['impacted_products'].message_type = _PRODUCT
_RESULT.fields_by_name['msbulletin'].message_type = _MSBULLETIN
DESCRIPTOR.message_types_by_name['Product'] = _PRODUCT
DESCRIPTOR.message_types_by_name['Msbulletin'] = _MSBULLETIN
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Product = _reflection.GeneratedProtocolMessageType('Product', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCT,
  '__module__' : 'msbulletin_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.msbulletin.Product)
  })
_sym_db.RegisterMessage(Product)

Msbulletin = _reflection.GeneratedProtocolMessageType('Msbulletin', (_message.Message,), {
  'DESCRIPTOR' : _MSBULLETIN,
  '__module__' : 'msbulletin_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.msbulletin.Msbulletin)
  })
_sym_db.RegisterMessage(Msbulletin)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'msbulletin_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.msbulletin.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rust.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rust.proto',
  package='strobesbufs.scrappers.rust',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\nrust.proto\x12\x1astrobesbufs.scrappers.rust\"\xc1\x01\n\x04Rust\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0b\n\x03\x63ve\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x18\n\x10\x61\x66\x66\x65\x63ted_package\x18\x06 \x01(\t\x12\x16\n\x0epublished_date\x18\x07 \x01(\t\x12\x18\n\x10patched_versions\x18\x08 \x03(\t\x12\x0c\n\x04tags\x18\t \x03(\t\x12\x12\n\nreferences\x18\n \x03(\t\"8\n\x06Result\x12.\n\x04rust\x18\x01 \x03(\x0b\x32 .strobesbufs.scrappers.rust.Rustb\x06proto3'
)




_RUST = _descriptor.Descriptor(
  name='Rust',
  full_name='strobesbufs.scrappers.rust.Rust',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.rust.Rust.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.rust.Rust.cve', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.scrappers.rust.Rust.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='strobesbufs.scrappers.rust.Rust.title', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='strobesbufs.scrappers.rust.Rust.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affected_package', full_name='strobesbufs.scrappers.rust.Rust.affected_package', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_date', full_name='strobesbufs.scrappers.rust.Rust.published_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patched_versions', full_name='strobesbufs.scrappers.rust.Rust.patched_versions', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='strobesbufs.scrappers.rust.Rust.tags', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='references', full_name='strobesbufs.scrappers.rust.Rust.references', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=236,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.rust.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rust', full_name='strobesbufs.scrappers.rust.Result.rust', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=294,
)

_RESULT.fields_by_name['rust'].message_type = _RUST
DESCRIPTOR.message_types_by_name['Rust'] = _RUST
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Rust = _reflection.GeneratedProtocolMessageType('Rust', (_message.Message,), {
  'DESCRIPTOR' : _RUST,
  '__module__' : 'rust_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.rust.Rust)
  })
_sym_db.RegisterMessage(Rust)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'rust_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.rust.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/canis/canis.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/canis/canis.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dstrobesbufs/canis/canis.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x82\x01\n\x05Input\x12)\n\x08new_bugs\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08old_bugs\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08\x66\x65\x61tures\x18\x03 \x01(\t\x12\x11\n\tthreshold\x18\x04 \x01(\x02\"3\n\x07Results\x12(\n\x07results\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\'\n\x05\x43\x61nis\x12\x1e\n\x08RunCanis\x12\x06.Input\x1a\x08.Results\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_INPUT = _descriptor.Descriptor(
  name='Input',
  full_name='Input',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_bugs', full_name='Input.new_bugs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_bugs', full_name='Input.old_bugs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='Input.features', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='Input.threshold', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=194,
)


_RESULTS = _descriptor.Descriptor(
  name='Results',
  full_name='Results',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='Results.results', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=247,
)

_INPUT.fields_by_name['new_bugs'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_INPUT.fields_by_name['old_bugs'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_RESULTS.fields_by_name['results'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['Input'] = _INPUT
DESCRIPTOR.message_types_by_name['Results'] = _RESULTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Input = _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), {
  'DESCRIPTOR' : _INPUT,
  '__module__' : 'strobesbufs.canis.canis_pb2'
  # @@protoc_insertion_point(class_scope:Input)
  })
_sym_db.RegisterMessage(Input)

Results = _reflection.GeneratedProtocolMessageType('Results', (_message.Message,), {
  'DESCRIPTOR' : _RESULTS,
  '__module__' : 'strobesbufs.canis.canis_pb2'
  # @@protoc_insertion_point(class_scope:Results)
  })
_sym_db.RegisterMessage(Results)



_CANIS = _descriptor.ServiceDescriptor(
  name='Canis',
  full_name='Canis',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=249,
  serialized_end=288,
  methods=[
  _descriptor.MethodDescriptor(
    name='RunCanis',
    full_name='Canis.RunCanis',
    index=0,
    containing_service=None,
    input_type=_INPUT,
    output_type=_RESULTS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CANIS)

DESCRIPTOR.services_by_name['Canis'] = _CANIS

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: php_security.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='php_security.proto',
  package='strobesbufs.scrappers.php_security',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12php_security.proto\x12\"strobesbufs.scrappers.php_security\"I\n\x06\x42ranch\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0epublished_date\x18\x02 \x01(\t\x12\x19\n\x11\x61\x66\x66\x65\x63ted_versions\x18\x03 \x03(\t\"\x8b\x01\n\x0bPhpSecurity\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03\x63ve\x18\x03 \x01(\t\x12\x12\n\nreferences\x18\x04 \x03(\t\x12<\n\x08\x62ranches\x18\x05 \x03(\x0b\x32*.strobesbufs.scrappers.php_security.Branch\"O\n\x06Result\x12\x45\n\x0cphp_security\x18\x01 \x03(\x0b\x32/.strobesbufs.scrappers.php_security.PhpSecurityb\x06proto3'
)




_BRANCH = _descriptor.Descriptor(
  name='Branch',
  full_name='strobesbufs.scrappers.php_security.Branch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='strobesbufs.scrappers.php_security.Branch.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_date', full_name='strobesbufs.scrappers.php_security.Branch.published_date', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affected_versions', full_name='strobesbufs.scrappers.php_security.Branch.affected_versions', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=131,
)


_PHPSECURITY = _descriptor.Descriptor(
  name='PhpSecurity',
  full_name='strobesbufs.scrappers.php_security.PhpSecurity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.php_security.PhpSecurity.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='strobesbufs.scrappers.php_security.PhpSecurity.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.php_security.PhpSecurity.cve', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='references', full_name='strobesbufs.scrappers.php_security.PhpSecurity.references', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branches', full_name='strobesbufs.scrappers.php_security.PhpSecurity.branches', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=273,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.php_security.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='php_security', full_name='strobesbufs.scrappers.php_security.Result.php_security', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=354,
)

_PHPSECURITY.fields_by_name['branches'].message_type = _BRANCH
_RESULT.fields_by_name['php_security'].message_type = _PHPSECURITY
DESCRIPTOR.message_types_by_name['Branch'] = _BRANCH
DESCRIPTOR.message_types_by_name['PhpSecurity'] = _PHPSECURITY
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Branch = _reflection.GeneratedProtocolMessageType('Branch', (_message.Message,), {
  'DESCRIPTOR' : _BRANCH,
  '__module__' : 'php_security_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.php_security.Branch)
  })
_sym_db.RegisterMessage(Branch)

PhpSecurity = _reflection.GeneratedProtocolMessageType('PhpSecurity', (_message.Message,), {
  'DESCRIPTOR' : _PHPSECURITY,
  '__module__' : 'php_security_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.php_security.PhpSecurity)
  })
_sym_db.RegisterMessage(PhpSecurity)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'php_security_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.php_security.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: alienvault.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='alienvault.proto',
  package='strobesbufs.scrappers.alienvault',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x61lienvault.proto\x12 strobesbufs.scrappers.alienvault\"\xa9\x03\n\nAlienvault\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0b\n\x03\x63ve\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x63vss2_vector\x18\x04 \x01(\t\x12\x1b\n\x13\x63vss2_exploit_score\x18\x05 \x01(\x02\x12\r\n\x05\x63vss2\x18\x06 \x01(\x02\x12\x14\n\x0c\x63vss3_vector\x18\x07 \x01(\t\x12\x1b\n\x13\x63vss3_exploit_score\x18\x08 \x01(\x02\x12\r\n\x05\x63vss3\x18\t \x01(\x02\x12\x10\n\x08products\x18\n \x03(\t\x12\x11\n\tseen_wild\x18\x0b \x01(\x08\x12\x0b\n\x03\x63we\x18\x0c \x01(\t\x12\x15\n\rlast_modified\x18\r \x01(\t\x12\x16\n\x0epublished_date\x18\x0e \x01(\t\x12\x12\n\nreferences\x18\x0f \x03(\t\x12\x0c\n\x04tags\x18\x10 \x03(\t\x12\x18\n\x10priority_private\x18\x11 \x01(\x02\x12\x17\n\x0fpriority_public\x18\x12 \x01(\x02\x12\x0f\n\x07\x65xploit\x18\x13 \x01(\x08\x12\x0f\n\x07malware\x18\x14 \x01(\x08\x12\r\n\x05patch\x18\x15 \x01(\x08\"J\n\x06Result\x12@\n\nalienvault\x18\x01 \x03(\x0b\x32,.strobesbufs.scrappers.alienvault.Alienvaultb\x06proto3'
)




_ALIENVAULT = _descriptor.Descriptor(
  name='Alienvault',
  full_name='strobesbufs.scrappers.alienvault.Alienvault',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.alienvault.Alienvault.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.alienvault.Alienvault.cve', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='strobesbufs.scrappers.alienvault.Alienvault.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss2_vector', full_name='strobesbufs.scrappers.alienvault.Alienvault.cvss2_vector', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss2_exploit_score', full_name='strobesbufs.scrappers.alienvault.Alienvault.cvss2_exploit_score', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss2', full_name='strobesbufs.scrappers.alienvault.Alienvault.cvss2', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss3_vector', full_name='strobesbufs.scrappers.alienvault.Alienvault.cvss3_vector', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss3_exploit_score', full_name='strobesbufs.scrappers.alienvault.Alienvault.cvss3_exploit_score', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss3', full_name='strobesbufs.scrappers.alienvault.Alienvault.cvss3', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='products', full_name='strobesbufs.scrappers.alienvault.Alienvault.products', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seen_wild', full_name='strobesbufs.scrappers.alienvault.Alienvault.seen_wild', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cwe', full_name='strobesbufs.scrappers.alienvault.Alienvault.cwe', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_modified', full_name='strobesbufs.scrappers.alienvault.Alienvault.last_modified', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_date', full_name='strobesbufs.scrappers.alienvault.Alienvault.published_date', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='references', full_name='strobesbufs.scrappers.alienvault.Alienvault.references', index=14,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='strobesbufs.scrappers.alienvault.Alienvault.tags', index=15,
      number=16, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority_private', full_name='strobesbufs.scrappers.alienvault.Alienvault.priority_private', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority_public', full_name='strobesbufs.scrappers.alienvault.Alienvault.priority_public', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exploit', full_name='strobesbufs.scrappers.alienvault.Alienvault.exploit', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='malware', full_name='strobesbufs.scrappers.alienvault.Alienvault.malware', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patch', full_name='strobesbufs.scrappers.alienvault.Alienvault.patch', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=480,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.alienvault.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alienvault', full_name='strobesbufs.scrappers.alienvault.Result.alienvault', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=556,
)

_RESULT.fields_by_name['alienvault'].message_type = _ALIENVAULT
DESCRIPTOR.message_types_by_name['Alienvault'] = _ALIENVAULT
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Alienvault = _reflection.GeneratedProtocolMessageType('Alienvault', (_message.Message,), {
  'DESCRIPTOR' : _ALIENVAULT,
  '__module__' : 'alienvault_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.alienvault.Alienvault)
  })
_sym_db.RegisterMessage(Alienvault)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'alienvault_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.alienvault.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: talos.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='talos.proto',
  package='strobesbufs.scrappers.talos',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0btalos.proto\x12\x1bstrobesbufs.scrappers.talos\"\x9b\x01\n\x05Talos\x12\r\n\x05title\x18\x01 \x01(\t\x12\x12\n\nreferences\x18\x02 \x03(\t\x12\x0b\n\x03\x63ve\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\x12\x0c\n\x04\x63vss\x18\x06 \x01(\x02\x12\x0f\n\x07summary\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x10\n\x08timeline\x18\t \x03(\t\";\n\x06Result\x12\x31\n\x05talos\x18\x01 \x03(\x0b\x32\".strobesbufs.scrappers.talos.Talosb\x06proto3'
)




_TALOS = _descriptor.Descriptor(
  name='Talos',
  full_name='strobesbufs.scrappers.talos.Talos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='strobesbufs.scrappers.talos.Talos.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='references', full_name='strobesbufs.scrappers.talos.Talos.references', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.talos.Talos.cve', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='strobesbufs.scrappers.talos.Talos.date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.talos.Talos.source', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss', full_name='strobesbufs.scrappers.talos.Talos.cvss', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='strobesbufs.scrappers.talos.Talos.summary', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='strobesbufs.scrappers.talos.Talos.description', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeline', full_name='strobesbufs.scrappers.talos.Talos.timeline', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=200,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.talos.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='talos', full_name='strobesbufs.scrappers.talos.Result.talos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=261,
)

_RESULT.fields_by_name['talos'].message_type = _TALOS
DESCRIPTOR.message_types_by_name['Talos'] = _TALOS
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Talos = _reflection.GeneratedProtocolMessageType('Talos', (_message.Message,), {
  'DESCRIPTOR' : _TALOS,
  '__module__' : 'talos_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.talos.Talos)
  })
_sym_db.RegisterMessage(Talos)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'talos_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.talos.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: debian.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='debian.proto',
  package='strobesbufs.scrappers.debian',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0c\x64\x65\x62ian.proto\x12\x1cstrobesbufs.scrappers.debian\x1a\x1cgoogle/protobuf/struct.proto\"J\n\x08Releases\x12-\n\x0crepositories\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07urgency\x18\x02 \x01(\t\"\x83\x01\n\x06\x44\x65\x62ian\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05scope\x18\x03 \x01(\t\x12\x0b\n\x03\x63ve\x18\x04 \x01(\t\x12\x38\n\x08releases\x18\x05 \x03(\x0b\x32&.strobesbufs.scrappers.debian.Releases\">\n\x06Result\x12\x34\n\x06\x64\x65\x62ian\x18\x01 \x03(\x0b\x32$.strobesbufs.scrappers.debian.Debianb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_RELEASES = _descriptor.Descriptor(
  name='Releases',
  full_name='strobesbufs.scrappers.debian.Releases',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repositories', full_name='strobesbufs.scrappers.debian.Releases.repositories', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='urgency', full_name='strobesbufs.scrappers.debian.Releases.urgency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=150,
)


_DEBIAN = _descriptor.Descriptor(
  name='Debian',
  full_name='strobesbufs.scrappers.debian.Debian',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.debian.Debian.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='strobesbufs.scrappers.debian.Debian.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='strobesbufs.scrappers.debian.Debian.scope', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.debian.Debian.cve', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='releases', full_name='strobesbufs.scrappers.debian.Debian.releases', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=284,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.debian.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='debian', full_name='strobesbufs.scrappers.debian.Result.debian', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=348,
)

_RELEASES.fields_by_name['repositories'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_DEBIAN.fields_by_name['releases'].message_type = _RELEASES
_RESULT.fields_by_name['debian'].message_type = _DEBIAN
DESCRIPTOR.message_types_by_name['Releases'] = _RELEASES
DESCRIPTOR.message_types_by_name['Debian'] = _DEBIAN
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Releases = _reflection.GeneratedProtocolMessageType('Releases', (_message.Message,), {
  'DESCRIPTOR' : _RELEASES,
  '__module__' : 'debian_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.debian.Releases)
  })
_sym_db.RegisterMessage(Releases)

Debian = _reflection.GeneratedProtocolMessageType('Debian', (_message.Message,), {
  'DESCRIPTOR' : _DEBIAN,
  '__module__' : 'debian_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.debian.Debian)
  })
_sym_db.RegisterMessage(Debian)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'debian_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.debian.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nvd.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='nvd.proto',
  package='strobesbufs.scrappers.nvd',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tnvd.proto\x12\x19strobesbufs.scrappers.nvd\x1a\x1cgoogle/protobuf/struct.proto\"I\n\x03Nvd\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0b\n\x03\x63ve\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"5\n\x06Result\x12+\n\x03nvd\x18\x01 \x03(\x0b\x32\x1e.strobesbufs.scrappers.nvd.Nvdb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_NVD = _descriptor.Descriptor(
  name='Nvd',
  full_name='strobesbufs.scrappers.nvd.Nvd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.nvd.Nvd.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.nvd.Nvd.cve', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='strobesbufs.scrappers.nvd.Nvd.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=143,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.nvd.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nvd', full_name='strobesbufs.scrappers.nvd.Result.nvd', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=198,
)

_NVD.fields_by_name['data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_RESULT.fields_by_name['nvd'].message_type = _NVD
DESCRIPTOR.message_types_by_name['Nvd'] = _NVD
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Nvd = _reflection.GeneratedProtocolMessageType('Nvd', (_message.Message,), {
  'DESCRIPTOR' : _NVD,
  '__module__' : 'nvd_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.nvd.Nvd)
  })
_sym_db.RegisterMessage(Nvd)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'nvd_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.nvd.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)
